##  Internal Fields
Fields that start with the lx prefix, such as lxProductCategory, are internal fields that are primarily used for integrations and various other features. When creating custom fields, do not add the lx prefix to field keys.
**Caution**
Modifying internal fields, including deleting, changing, adding, or removing field values, may lead to unexpected behavior. We don’t recommend deleting or modifying internal fields. If necessary, you can make these fields invisible on the fact sheet by moving them to the Unused Fields and Relations section.
